@@ -87,7 +87,7 @@ chalmers_gem <- function(organism = 'Human', orphans = TRUE) {
 
     metabolites <-
         raw %>%
-        chalmers_gem_matlab_tibble(mets, metNames, metFormulas, inchis) %>%
+        gem_matlab_tibble(mets, metNames, metFormulas, inchis) %>%
         mutate(
             across(
                 everything(),
@@ -98,7 +98,7 @@ chalmers_gem <- function(organism = 'Human', orphans = TRUE) {
 
     reactions <-
         raw %>%
-        chalmers_gem_matlab_tibble(rxns, lb, ub, rev, grRules)  %>%
+        gem_matlab_tibble(rxns, lb, ub, rev, grRules)  %>%
         rename(reversible = rev) %>%
         mutate(
             rxns = unlist(rxns),
@@ -112,10 +112,10 @@ chalmers_gem <- function(organism = 'Human', orphans = TRUE) {
                 map(str_split, ' and ') %>%
                 map(discard, is_empty_2)
             ),
-            orphan = are_na(map_lgl(
+            orphan = map_lgl(
                 grRules,
-                ~any(map_lgl(.x, ~any(str_detect(.x, '^\\d+$'))))
-            )),
+                ~any(map_lgl(.x, ~any(is.na(.x))))
+            ),
             reactants = map2(
                 1L:n(),
                 direction,
@@ -527,41 +527,3 @@ chalmers_gem_raw <- function(organism = 'Human') {
     load_success()
 
 }
-
-
-#' Tibble from Chalmers GEM Matlab object
-#'
-#' @param matlab Chalmers GEM in an R object loaded from the Matlab
-#'     dump.
-#' @param ... Variable names: should contain either only reaction or
-#'     metabolite variables, otherwise num of rows won't be uniform.
-#'
-#' @return Tibble with the requested variables.
-#'
-#' @importFrom purrr map
-#' @importFrom tibble as_tibble
-#' @importFrom dplyr pull
-#' @importFrom magrittr %>% extract extract2 equals
-#' @importFrom rlang enquos
-#'
-#' @noRd
-chalmers_gem_matlab_tibble <- function(matlab, ...) {
-
-    cols <-
-        enquos(...) %>%
-        map_chr(.nse_ensure_str)
-
-    matlab %>%
-    as_tibble %>%
-    pull(1L) %>%
-    extract(,,1L) %>%
-    map(
-        function(x) {
-            if (x %>% dim %>% equals(1L) %>% all) x %>% extract(1L,1L) else x
-        }
-    ) %>%
-    extract(cols) %>%
-    map(extract,,1L) %>%
-    as_tibble
-
-}
